@@ -1,10 +1,11 @@
 #!/bin/bash
 # Build config for build.sh
 APP_NAME=moz-gnome-pm
+APP_VER=0.2
 CHROME_PROVIDERS="content locale"
 CLEAN_UP=1
 ROOT_FILES="gnome-session-inhibit-helper.py chrome.manifest"
-ROOT_DIRS="components"
+ROOT_DIRS="defaults components"
 BEFORE_BUILD=
 AFTER_BUILD=
 XUL_SDK=/usr/lib/xulrunner-devel-`xulrunner --gre-version`
